@@ -22,13 +22,16 @@ else:
 __all__ = (
     "ListDeviceEventsPaginatorName",
     "ListDevicesPaginatorName",
+    "IoT1ClickDevicesServiceServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
 
 ListDeviceEventsPaginatorName = Literal["list_device_events"]
 ListDevicesPaginatorName = Literal["list_devices"]
+IoT1ClickDevicesServiceServiceName = Literal["iot1click-devices"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -60,6 +63,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -182,6 +186,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -330,4 +335,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_device_events", "list_devices"]
